.. _cli:

CLI
===

.. toctree::
   :maxdepth: 1

   elhaz <elhaz>
   elhaz config <elhaz-config>
   elhaz daemon <elhaz-daemon>
   elhaz exec <elhaz-exec>
   elhaz export <elhaz-export>
   elhaz shell <elhaz-shell>
   elhaz whoami <elhaz-whoami>
